<?php

/**
 *
 * @package phpBB Extension - Arabic Month names
 * @copyright (c) 2017 Saeed@hubaishan.com
 *
 */

namespace hubaishan\arabicmonthnames\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event listener
 */
class main_listener implements EventSubscriberInterface {

	/** @var \phpbb\user */
	protected $user;

	/** @var \phpbb\config\config */
	protected $config;
	
	/* @var \phpbb\language\language */
	//protected $language;
	
	/** @var \phpbb\template\template */
	protected $template;
	
	/** @var \phpbb\request\request  */
	protected $request;
	
	/**
	 * Constructor
	 *
	 * @param \phpbb\user $user User object
	 */
	public function __construct(\phpbb\config\config $config, \phpbb\user $user, \phpbb\template\template $template, \phpbb\request\request $request)
	{	
		//$this->language	= $language;
		$this->config	= $config;
		$this->user		= $user;
		$this->template	= $template;
		$this->request	= $request;
	}


	static public function getSubscribedEvents() {
		return array(
			'core.user_setup' => 'load_language_on_setup',
			'core.acp_board_config_edit_add'	=> 'acp_board_config_edit_add',
			'core.ucp_prefs_personal_data'		=> 'ucp_prefs_personal_data',
			'core.ucp_prefs_personal_update_data'	=> 'ucp_prefs_personal_update_data',
		);
	}

	public function load_language_on_setup($event) {
		$ar_month_names	=(int) ($this->user->data['user_ar_month_names'] > 0)? $this->user->data['user_ar_month_names'] :  $this->config['ar_month_names'];
		$lang_set_ext	= $event['lang_set_ext'];
		if (($event['user_lang_name'] == 'ar') && ($ar_month_names > 1))
		{
			$month_names	= array(
				2 => 'syriannames',
				3 => 'frenchnames',
				4 => 'morocconames',
				5 => 'mauritanianames',
			);
			
			if ($ar_month_names < 6)
			{
				$lang_set_ext[] = array(
					'ext_name' => 'hubaishan/arabicmonthnames',
					'lang_set' => $month_names[$ar_month_names],
				);
			}
		}
		$lang_set_ext[] = array(
			'ext_name' => 'hubaishan/arabicmonthnames',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
		
	}

	public function acp_board_config_edit_add($event) {

		if ($event['mode'] == 'settings')
		{
			$this->user->add_lang_ext('hubaishan/arabicmonthnames', 'common');
			$display_vars = $event['display_vars'];

			$new_vars = array(
				'ar_month_names'	=> array('lang' => 'ACP_ARABIC_MONTH_NAMES',	'validate' => 'int:1:5',	'type' => 'text:1:1',	 'explain' => true), 
			);
			
			$display_vars['vars'] = phpbb_insert_config_array($display_vars['vars'], $new_vars, array('after' => 'default_dateformat'));
			$event['display_vars'] = $display_vars;
		}
		
		
	}
	
	public function ucp_prefs_personal_data($event)
	{
		$data = $event['data'];
		
		$data = array_merge($data, array(
			'ar_month_names'	=> $this->request->variable('ar_month_names', $this->user->data['user_ar_month_names']),
		));
		
		
		$ar_month_names_options = $this->general_select(array(
			0 => 'AR_MONTH_NAMES_SYSTEM',
			1 => 'AR_MONTH_NAMES_ENGLISH',
			2 => 'AR_MONTH_NAMES_SYRIAN',
			3 => 'AR_MONTH_NAMES_FRENCH',
			4 => 'AR_MONTH_NAMES_MOROCCO',
			5 => 'AR_MONTH_NAMES_MAURITANIA',
		), $data['ar_month_names']
		);
		
		
		
		$this->template->assign_vars(array(
			'S_AR_MONTH_NAMES_OPTIONS' => $ar_month_names_options,
		));
		
		$event['data'] = $data;
	}
	
	public function ucp_prefs_personal_update_data($event)
	{
		$data = $event['data'];
		$sql_ary = $event['sql_ary'];
		
		$sql_ary = array_merge($sql_ary, array(
			'user_ar_month_names'	=> $data['ar_month_names'],
		));
		
		$event['sql_ary'] = $sql_ary;
	}
	
	/**
	* Options to pick an element from array
	*
	* @param	array 		$options_array		An array contains the element to include in select options, Array key is the value, Array value is language key
	* @param	string		$default			An element to select
	*
	* @return	string		Returns a string containing the options for the selector.
	*/
	
	public function general_select($options_array, $default = '')
	{
		
		$general_options = '';
		foreach ($options_array as $key => $value)
		{
			$selected = ($key == $default) ? ' selected="selected"' : '';
			$general_options .= '<option value="' . $key . '"' . $selected . '>'. $this->user->lang($value) . '</option>';
		}
		
		return $general_options;
	}
	
	
}